@@ -78,6 +78,7 @@ class Dataset:
         file_path=None,
         folder=None,
         tag=None,
+        data={},  # will get replaced if it's not initialized empty.
         data_type=None,
         file_type=None,
         verbose=True,
@@ -87,7 +88,7 @@ class Dataset:
         """
         self.type = "Dataset"
         self.verbose = verbose
-        self.empty = True  # will be set to false below if necessary
+        self.empty = False  # will be set to True below if necessary
         if folder is not None:  # then go to the folder and remember how to get back
             back = os.getcwd()
             os.chdir(folder)
@@ -122,22 +123,25 @@ class Dataset:
                 datas += [data]
             self.data = synchronize(datas, verbose=verbose)
             sort_time(self.data)
-        else:
+
+        if folder is not None:  # time to go home.
+            os.chdir(back)
+        if not hasattr(self, "data"):
+            self.data = data
+        if data_type is not None:
+            self.data["data_type"] = data_type
+        if not "data_cols" in self.data:
             print(
                 "Warning!!! Please specify file_name and/or folder."
                 + " Returning an empty dataset"
             )
             self.empty = True
-
-        if folder is not None:  # time to go home.
-            os.chdir(back)
-        if data_type is not None:
-            self.data["data_type"] = data_type
         self.update_with_data()
 
     def update_with_data(self):
         if not hasattr(self, "data") or "data_cols" not in self.data:
             print("Warning!!! Empty dataset.")
+            self.data = {"data_cols": set([]), "timecols": {}}
             return
         for key, value in self.data.items():
             if key not in self.data["data_cols"]:
@@ -176,12 +180,10 @@ class Dataset:
         """
         try:
             return getattr(self, key)
-        except AttributeError:
+        except (AttributeError, TypeError):
             raise KeyError(
-                "Dataset has no attribute "
-                + key
-                + " and Dataset.data has no key "
-                + key
+                f"Dataset has no attribute {key}"
+                + f" and Dataset.data has no key {key}"
             )
 
     def __setitem__(self, key, value):
@@ -201,9 +203,15 @@ class Dataset:
         new_dataset = Dataset(new_data)
         return new_dataset
 
-    def add_data_col(self, col, value, col_type=None):
+    def add_data_col(self, col, value, timecol=None, col_type=None):
         self.data[col] = value
+        if not "data_cols" in self.data:
+            self.data["data_cols"] = set([])
         self.data["data_cols"].add(col)
+        if timecol is not None:
+            if "timecols" not in self.data:
+                self.data["timecols"] = {}
+            self.data["timecols"][col] = timecol
         if col_type is not None:
             if "col_types" not in self.data:
                 self.data["col_types"] = {}
@@ -217,7 +225,7 @@ class Dataset:
         if col in self.data_cols:
             self.data[col] = np.append(self.data[col], value)
         else:
-            self.add_data_col(col, value, col_type)
+            self.add_data_col(col, value, col_type=col_type)
 
     def save(self, file_name, data_type=None):
         if data_type is None:
@@ -397,7 +405,7 @@ class Dataset:
                         cycles=cycles,
                         cycle_str=key,
                         verbose=verbose,
-                        **kwargs
+                        **kwargs,
                     )
         new_dataset = Dataset(new_data)
         for attr in metadata_items:
@@ -468,6 +476,10 @@ class CyclicVoltammagram(Dataset):
                 step = 1
             key = list(range(start, stop, step))
         if type(key) in [int, list]:
+            if type(key) is list and not all([type(i) is int for i in key]):
+                print("can't get an item of type list unless all elements are int")
+                print(f"you tried to get key = {key}.")
+                raise AttributeError
             return CyclicVoltammagram(
                 self.cut(cycle=key, t_zero="start", verbose=False), verbose=False
             )
@@ -792,7 +804,8 @@ class CyclicVoltammagram(Dataset):
 
                     diff.append_to_data_col(
                         col, y_diff, col_type="EC"
-                    )  # make it all bloody EC
+                    )  # if we say the col_type is EC,
+                    # then it should recognize "time/s" as the timecol.
 
         diff["tspan"] = [diff[t_str][0], diff[t_str][-1]]
         diff = CyclicVoltammagram(diff)
